" Vim syntax file
" Language:	GtkScript
" Maintainer:	Peter van Eerten <peter AT gtk-server DOT org>
" Last Change:	February 26, 2006

" -------------------------------------------------------------------------------
" Based on the BASIC syntax file from Allan Kelly.
" Edit the '/usr/share/vim/vim63/filetype.vim' file to add the '*.gtks' type:
"
" au BufNewFile,BufRead *.gtks			setf gtks
" -------------------------------------------------------------------------------

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

" A bunch of useful keywords
syn keyword basicStatement	BEEP beep CHDIR chdir CLS cls CLOSE close COLOR color
syn keyword basicStatement	DIM dim DO do UNTIL until ENVIRON environ END end
syn keyword basicStatement	FOR for TO to STEP step GET get
syn keyword basicStatement	IF if THEN then ELSE else ENDIF endif INPUT input
syn keyword basicStatement	KILL kill LET let LSET lset MKDIR mkdir NAME name
syn keyword basicStatement	OPEN open OUTPUT output APPEND append AS as PRINT print
syn keyword basicStatement	PUT put RANDOMIZE randomize READ read DATA data
syn keyword basicStatement	RESTORE restore RMDIR rmdir RSET rset SEEK seek SWAP swap
syn keyword basicStatement	SYSTEM system WHILE while WEND wend CALL call NULL null
syn keyword basicStatement	SLEEP sleep SUB sub ENDSUB endsub NEXT next

syn keyword basicFunction	ABS abs ACOS acos ASC asc ASIN asin ATN atn
syn keyword basicFunction	CINT cint COS cos EOF eof EXP exp FREEFILE freefile
syn keyword basicFunction	INSTR instr INT int LEN len LOC loc LOCATE locate LOF lof
syn keyword basicFunction	LOG log MOD mod NOT not RND rnd SGN sgn SIN sin
syn keyword basicFunction	SQR sqr TAN tan TIMER timer VAL val EXIST exist

syn keyword basicTodo contained	TODO

"integer number, or floating point number without a dot.
syn match  basicNumber		"\<\d\+\>"
"floating point number, with dot
syn match  basicNumber		"\<\d\+\.\d*\>"
"floating point number, starting with a dot
syn match  basicNumber		"\.\d\+\>"

" String functions
syn match  stringFunction	"[Ll][Ee][Ff][Tt]\$\|[Rr][Ii][Gg][Hh][Tt]\$\|[Mm][Ii][Dd]\$"
syn match  stringFunction	"[Aa][Rr][Gg][Ss]\$\|[Cc][Hh][Rr]\$\|[Dd][Aa][Tt][Ee]\$"
syn match  stringFunction	"[Ee][Nn][Vv][Ii][Rr][Oo][Nn]\$\|[Hh][Ee][Xx]\$\|[Ii][Nn][Kk][Ee][Yy]\$"
syn match  stringFunction	"[Ll][Oo][Ww][Ee][Rr]\$\|[Ll][Tt][Rr][Ii][Mm]\$\|[Oo][Cc][Tt]\$"
syn match  stringFunction	"[Rr][Tt][Rr][Ii][Mm]\$\|[Ss][Pp][Aa][Cc][Ee]\$\|[Ss][Tt][Rr]\$"
syn match  stringFunction	"[Ss][Tt][Rr][Ii][Nn][Gg]\$\|[Tt][Ii][Mm][Ee]\$\|[Uu][Pp][Pp][Ee][Rr]\$"

"GTK or GDK function
syn match  gtkFunction		"[Gg][TtDd][Kk][_][_a-zA-Z0-9]\+"

"Shell reference
syn region  shellReference	start="^\#\!" end="$"

" String and Character contstants
syn match   basicSpecial contained "\\\d\d\d\|\\."
syn region  basicString		  start=+"+  skip=+\\\\\|\\"+  end=+"+  contains=basicSpecial

syn region  basicComment	start="REM" end="$" contains=basicTodo
syn region  basicComment	start="^[ \t]*'" end="$" contains=basicTodo
syn region  basicLineNumber	start="^\d" end="\s"
syn match   basicTypeSpecifier  "[a-zA-Z0-9][\$%&!#]"ms=s+1
" Used with OPEN statement
syn match   basicFilenumber  "#\d\+"
"syn sync ccomment basicComment
" syn match   basicMathsOperator "[<>+\*^/\\=-]"
syn match   basicMathsOperator   "-\|=\|[:<>+\*^/\\]\|AND\|OR\|XOR"

" Define the default highlighting.
" For version 5.7 and earlier: only when not done already
" For version 5.8 and later: only when an item doesn't have highlighting yet
if version >= 508 || !exists("did_basic_syntax_inits")
  if version < 508
    let did_basic_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif

  HiLink basicLabel		Label
  HiLink basicConditional	Conditional
  HiLink basicRepeat		Repeat
  HiLink basicLineNumber	Comment
  HiLink basicNumber		Number
  HiLink basicError		Error
  HiLink basicStatement		Statement
  HiLink basicString		String
  HiLink basicComment		Comment
  HiLink basicSpecial		Special
  HiLink basicTodo		Todo
  HiLink basicFunction		Identifier
  HiLink basicTypeSpecifier	Type
  HiLink basicFilenumber	basicTypeSpecifier
  HiLink gtkFunction		Identifier
  HiLink stringFunction		Identifier
  HiLink shellReference		Number
  HiLink basicMathsOperator	Statement

  delcommand HiLink
endif

let b:current_syntax = "gtks"
